widgetSize property
Size?
get
widgetSize
The size of the widget after the first frame.
Implementation
Size? get widgetSize => _widgetSize;
The size of the widget after the first frame.
Size? get widgetSize => _widgetSize;