builder property
Builder function that provides the scroll manager for building the UI.
Implementation
final Widget Function(
BuildContext context,
PostFrameScrollManager scrollManager,
)
builder;
Builder function that provides the scroll manager for building the UI.
final Widget Function(
BuildContext context,
PostFrameScrollManager scrollManager,
)
builder;