PostFrameScrollData class

Data class containing post-frame build information including scroll controllers.

Constructors

PostFrameScrollData({required BuildContext context, required Size? size, required PostFrameScrollManager scrollManager})
const

Properties

context BuildContext
The build context of the widget.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollManager PostFrameScrollManager
The scroll controller manager for accessing multiple controllers.
final
size Size?
The size of the widget after the first frame.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited