getController method
Gets a ScrollController by its key.
Returns null if no controller exists with the given key.
Implementation
ScrollController? getController(String key) => _controllers[key];
Gets a ScrollController by its key.
Returns null if no controller exists with the given key.
ScrollController? getController(String key) => _controllers[key];