getMaxScrollExtent method

double? getMaxScrollExtent(
  1. String key
)

Gets the max scroll extent of the controller with the given key.

Returns null if no controller exists or if it's not attached.

Implementation

double? getMaxScrollExtent(String key) {
  final controller = _controllers[key];
  if (controller == null || !controller.hasClients) return null;
  return controller.position.maxScrollExtent;
}