getMinScrollExtent method

double? getMinScrollExtent(
  1. String key
)

Gets the min scroll extent of the controller with the given key.

Returns null if no controller exists or if it's not attached.

Implementation

double? getMinScrollExtent(String key) {
  final controller = _controllers[key];
  if (controller == null || !controller.hasClients) return null;
  return controller.position.minScrollExtent;
}