operator [] method
Gets a ScrollController by its key using bracket notation.
Returns null if no controller exists with the given key.
Implementation
ScrollController? operator [](String key) => _controllers[key];
Gets a ScrollController by its key using bracket notation.
Returns null if no controller exists with the given key.
ScrollController? operator [](String key) => _controllers[key];